@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
  
 #ifndef ANGLEMEASURE_HPP_
@@ -50,6 +50,7 @@ public slots:
 	void enableAngleMeasure(bool b);
 
 private slots:
+	void updateMessageText();
 	void clearMessage();
 
 private:
@@ -58,6 +59,9 @@ private:
 	LinearFader lineVisible;
 	LinearFader messageFader;
 	QTimer* messageTimer;
+	QString messageEnabled;
+	QString messageLeftButton;
+	QString messageRightButton;
 	bool dragging;
 	Vec3d startPoint;
 	Vec3d endPoint;
@@ -71,7 +75,7 @@ private:
 	bool flagUseDmsFormat;
 	StelButton* toolbarButton;
 
-	void calculateEnds(void);
+	void calculateEnds();
 };
 
 
