@@ -23,7 +23,8 @@
 #include <QMap>
 
 class LogBookConfigDialog;
-class LogBookDialog;
+class ObservationsDialog;
+class SessionsDialog;
 class TargetsDialog;
 
 class QKeyEvent;
@@ -34,6 +35,7 @@ class QSqlTableModel;
 class QSqlQuery;
 
 class StelButton;
+class StelStyle;
 
 //! This is an example of a plug-in which can be dynamically loaded into stellarium
 class LogBook : public StelModule
@@ -48,6 +50,9 @@ public:
 	virtual bool configureGui(bool show=true);
 	virtual void draw(StelCore* core);
 	virtual double getCallOrder(StelModuleActionName actionName) const;
+	//! Returns the module-specific style sheet.
+	//! The main StelStyle instance should be passed.
+	const StelStyle getModuleStyleSheet(const StelStyle& style);
 	virtual void init();
 	virtual void setStelStyle(const QString& section);
 	virtual void update(double) {;}
@@ -77,13 +82,17 @@ private:
 	//! Insures that the database tables exist.  It not, calls createDatabaseStructures() to create them.
 	bool initializeDatabase();
 	
+	//Styles
+	QByteArray normalStyleSheet;
+	QByteArray nightStyleSheet;
+
 	//! reads a file line by line, and calls executeSql() with each line. Blank lines or SQL comments are ignored.
 	//! @param the file name that contains the SQL.
 	//! @return true if there was no error, false if there was an error.
 	bool processSqlFile(QString &fileName);
 
 	LogBookConfigDialog *configDialog;
-	LogBookDialog *mainDialog;
+	SessionsDialog *sessionsDialog;
 	TargetsDialog *targetsDialog;
 
 	//! flag used to track if we are in log book mode.
