@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2009 Timothy Reaves
+ * Copyright (C) 2011 Bogdan Marinov
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -13,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
 #ifndef _OCULARS_HPP_
@@ -32,7 +33,9 @@
 #define MIN_OCULARS_INI_VERSION 0.12
 
 QT_BEGIN_NAMESPACE
+class QAction;
 class QKeyEvent;
+class QMenu;
 class QMouseEvent;
 class QPixmap;
 class QSettings;
@@ -41,10 +44,13 @@ QT_END_NAMESPACE
 
 class StelButton;
 
-//! This is an example of a plug-in which can be dynamically loaded into stellarium
+//! Main class of the Oculars plug-in.
 class Oculars : public StelModule
 {
 	Q_OBJECT
+	//BM: Temporary, until the GUI is finalized and some other method of getting
+	//info from the main class is implemented.
+	friend class OcularsGuiPanel;
 
 public:
 	Oculars();
@@ -69,6 +75,10 @@ public:
 	virtual void update(double) {;}
 
 public slots:
+	//! Update the ocular, telescope and sensor lists after the removal of a member.
+	//! Necessary because of the way model/view management in the OcularDialog
+	//! is implemented.
+	void updateLists();
 	void ccdRotationReset();
 	void decrementCCDIndex();
 	void decrementOcularIndex();
@@ -80,13 +90,20 @@ public slots:
 	void incrementCCDIndex();
 	void incrementOcularIndex();
 	void incrementTelescopeIndex();
-	void rotateCCD(QString amount); //<! amount must be a number.
-	void selectCCDAtIndex(QString indexString); //<! indexString must be an integer, in the range of -1:ccds.count()
-	void selectOcularAtIndex(QString indexString);  //<! indexString must be an integer, in the range of -1:oculars.count()
-	void selectTelescopeAtIndex(QString indexString);  //<! indexString must be an integer, in the range of -1:telescopes.count()
+	void rotateCCD(QString amount); //!< amount must be a number.
+	void selectCCDAtIndex(QString indexString); //!< indexString must be an integer, in the range of -1:ccds.count()
+	void selectOcularAtIndex(QString indexString);  //!< indexString must be an integer, in the range of -1:oculars.count()
+	void selectTelescopeAtIndex(QString indexString);  //!< indexString must be an integer, in the range of -1:telescopes.count()
+	//! Toggles the sensor frame overlay.
+	void toggleCCD(bool show);
+	//! Toggles the sensor frame overlay (overloaded for blind switching).
 	void toggleCCD();
-	void toggleCrosshair();
+	void toggleCrosshairs(bool show = true);
+	//! Toggles the Telrad sight overlay.
+	void toggleTelrad(bool show);
+	//! Toggles the Telrad sight overlay (overloaded for blind switching).
 	void toggleTelrad();
+	void enableGuiPanel(bool enable = true);
 
 signals:
 	void selectedCCDChanged();
@@ -100,6 +117,7 @@ private slots:
 	void setRequireSelection(bool state);
 	void setScaleImageCircle(bool state);
 	void setScreenFOVForCCD();
+	void retranslateGui();
 	void setStelStyle(const QString& style);
 
 private:
@@ -142,13 +160,18 @@ private:
 	//! This method is called by the zoom() method, when this plugin is toggled on; it resets the zoomed view.
 	void zoomOcular();
 
+	void hideUsageMessageIfDisplayed();
+
+	//! Creates the sub-menu listing telescopes in the pop-up menu.
+	QMenu* addTelescopeSubmenu(QMenu* parent);
+
 	//! A list of all the oculars defined in the ini file.  Must have at least one, or module will not run.
 	QList<CCD *> ccds;
 	QList<Ocular *> oculars;
 	QList<Telescope *> telescopes;
-	int selectedCCDIndex; //<! index of the current CCD, in the range of -1:ccds.count().  -1 means no CCD is selected.
-	int selectedOcularIndex; //<! index of the current ocular, in the range of -1:oculars.count().  -1 means no ocular is selected.
-	int selectedTelescopeIndex; //<! index of the current telescope, in the range of -1:telescopes.count(). -1 means none is selected.
+	int selectedCCDIndex; //!< index of the current CCD, in the range of -1:ccds.count().  -1 means no CCD is selected.
+	int selectedOcularIndex; //!< index of the current ocular, in the range of -1:oculars.count().  -1 means no ocular is selected.
+	int selectedTelescopeIndex; //!< index of the current telescope, in the range of -1:telescopes.count(). -1 means none is selected.
 
 	QFont font;					//!< The font used for drawing labels.
 	bool flagShowCCD;				//!< flag used to track f we are in CCD mode.
@@ -158,21 +181,26 @@ private:
 	int usageMessageLabelID;	//!< the id of the label showing the usage message. -1 means it's not displayed.
 
 	bool flagAzimuthalGrid;		//!< Flag to track if AzimuthalGrid was displayed at activation.
+	bool flagGalacticGrid;		//!< Flag to track if GalacticGrid was displayed at activation.
 	bool flagEquatorGrid;		//!< Flag to track if EquatorGrid was displayed at activation.
 	bool flagEquatorJ2000Grid;	//!< Flag to track if EquatorJ2000Grid was displayed at activation.
 	bool flagEquatorLine;		//!< Flag to track if EquatorLine was displayed at activation.
 	bool flagEclipticLine;		//!< Flag to track if EclipticLine was displayed at activation.
 	bool flagMeridianLine;		//!< Flag to track if MeridianLine was displayed at activation.
+	bool flagHorizonLine;		//!< Flag to track if HorizonLine was displayed at activation.
+	bool flagGalacticPlaneLine;	//!< Flag to track if GalacticPlaneLine was displayed at activation.
 
-	double ccdRotationAngle;	//<! The angle to rotate the CCD bounding box. */
+	double ccdRotationAngle;	//!< The angle to rotate the CCD bounding box. */
 	double maxEyepieceAngle;	//!< The maximum aFOV of any eyepiece.
 	bool requireSelection;		//!< Read from the ini file, whether an object is required to be selected to zoom in.
 	bool useMaxEyepieceAngle;	//!< Read from the ini file, whether to scale the mask based aFOV.
+	//! Display the GUI control panel
+	bool guiPanelEnabled;
 
-	QSignalMapper* ccdRotationSignalMapper;  //<! Used to rotate the CCD. */
-	QSignalMapper* ccdsSignalMapper; //<! Used to determine which CCD was selected from the popup navigator. */
-	QSignalMapper* ocularsSignalMapper; //<! Used to determine which ocular was selected from the popup navigator. */
-	QSignalMapper* telescopesSignalMapper; //<! Used to determine which telescope was selected from the popup navigator. */
+	QSignalMapper* ccdRotationSignalMapper;  //!< Used to rotate the CCD. */
+	QSignalMapper* ccdsSignalMapper; //!< Used to determine which CCD was selected from the popup navigator. */
+	QSignalMapper* ocularsSignalMapper; //!< Used to determine which ocular was selected from the popup navigator. */
+	QSignalMapper* telescopesSignalMapper; //!< Used to determine which telescope was selected from the popup navigator. */
 
 	// for toolbar button
 	QPixmap* pxmapGlow;
@@ -183,6 +211,15 @@ private:
 	OcularDialog *ocularDialog;
 	bool ready; //!< A flag that determines that this module is usable.  If false, we won't open.
 
+	QAction* actionShowOcular;
+	QAction* actionShowCrosshairs;
+	QAction* actionShowSensor;
+	QAction* actionShowTelrad;
+	QAction* actionConfiguration;
+	QAction* actionMenu;
+
+	class OcularsGuiPanel* guiPanel;
+
 	//Styles
 	QByteArray normalStyleSheet;
 	QByteArray nightStyleSheet;
