@@ -62,7 +62,7 @@ OcularDialog::OcularDialog(Oculars* pluginPtr, QList<CCD *>* ccds, QList<Ocular
 	
 	validatorPositiveInt = new QIntValidator(0, std::numeric_limits<int>::max(), this);
 	validatorPositiveDouble = new QDoubleValidator(.0, std::numeric_limits<double>::max(), 24, this);
-	validatorOcularAFOV = new QIntValidator(35, 120, this);
+	validatorOcularAFOV = new QDoubleValidator(1.0, 120.0, 1, this);
 	validatorOcularEFL = new QDoubleValidator(1.0, 60.0, 1, this);
 	validatorTelescopeDiameter = new QDoubleValidator(1.0, 1000.0, 1, this);
 	validatorTelescopeFL = new QDoubleValidator(1.0, 10000.0, 1, this);
