@@ -19,6 +19,8 @@ my(%h);
 while(<STDIN>) {
 	chomp;
 	s/\s+$//;
+	$_ =~ /^2\s(\d+)\s/;
+	$h{'id'} = $1; 
 	if (/^1/) { $h{'tle1'} = $_; }
 	elsif (/^2/) {
 		$h{'tle2'} = $_;
@@ -27,7 +29,7 @@ while(<STDIN>) {
 	}
 	else { 
 		s/\s*\[[^\]]+\]\s*$//; 
-		$h{'id'} = $_; 
+		$h{'name'} = $_; 
 	}
 }
 
@@ -41,6 +43,7 @@ sub out {
 	print  "\t\t{\n";
 	print  "\t\t\t\"groups\": [$groups],\n";
 	print  "\t\t\t\"orbitVisible\": false,\n";
+	printf "\t\t\t\"name\": \"%s\",\n", $h{'name'};
 	printf "\t\t\t\"tle1\": \"%s\",\n", $h{'tle1'};
 	printf "\t\t\t\"tle2\": \"%s\",\n", $h{'tle2'};
 	print  "\t\t\t\"visible\": false\n";
