@@ -212,11 +212,13 @@ void Supernova::draw(StelCore* core, StelPainter& painter)
 
 	StelUtils::spheToRect(snra, snde, XYZ);
 	mag = getVMagnitude(core, true);
+	sd->preDrawPointSource(&painter);
 	
 	if (mag <= sd->getLimitMagnitude())
 	{
-		sd->computeRCMag(mag, rcMag);
-		sd->drawPointSource(&painter, Vec3f(XYZ[0], XYZ[1], XYZ[2]), rcMag, color, false);
+		sd->computeRCMag(mag, rcMag);		
+//		sd->drawPointSource(&painter, Vec3f(XYZ[0], XYZ[1], XYZ[2]), rcMag, color, false);
+		sd->drawPointSource(&painter, XYZ, rcMag, color, false);
 		painter.setColor(color[0], color[1], color[2], 1);
 		size = getAngularSize(NULL)*M_PI/180.*painter.getProjector()->getPixelPerRadAtCenter();
 		shift = 6.f + size/1.8f;
@@ -225,4 +227,6 @@ void Supernova::draw(StelCore* core, StelPainter& painter)
 			painter.drawText(XYZ, designation, 0, shift, shift, false);
 		}
 	}
+
+	sd->postDrawPointSource(&painter);
 }
