@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
 #include "StelMainGraphicsView.hpp"
@@ -101,8 +101,16 @@ Q_IMPORT_PLUGIN(SolarSystemEditor)
 Q_IMPORT_PLUGIN(TimeZoneConfiguration)
 #endif
 
-#ifdef USE_STATIC_PLUGIN_SUPERNOVAS
-Q_IMPORT_PLUGIN(Supernovas)
+#ifdef USE_STATIC_PLUGIN_SUPERNOVAE
+Q_IMPORT_PLUGIN(Supernovae)
+#endif
+
+#ifdef USE_STATIC_PLUGIN_QUASARS
+Q_IMPORT_PLUGIN(Quasars)
+#endif
+
+#ifdef USE_STATIC_PLUGIN_PULSARS
+Q_IMPORT_PLUGIN(Pulsars)
 #endif
 
 // Initialize static variables
@@ -274,10 +282,16 @@ void StelMainGraphicsView::init(QSettings* conf)
 #ifndef DISABLE_SCRIPTING
 	QString startupScript;
 	if (qApp->property("onetime_startup_script").isValid())
-		qApp->property("onetime_startup_script").toString();
+		startupScript = qApp->property("onetime_startup_script").toString();
 	else
 		startupScript = conf->value("scripts/startup_script", "startup.ssc").toString();
-	scriptMgr->runScript(startupScript);
+
+	// Use a queued slot call to start the script only once the main qApp event loop is running...
+	QMetaObject::invokeMethod(scriptMgr,
+				  "runScript",
+				  Qt::QueuedConnection,
+				  Q_ARG(QString, startupScript));
+
 #endif
 
 	QThread::currentThread()->setPriority(QThread::HighestPriority);
