@@ -28,10 +28,11 @@
 // To be decided: The following should be either 0 or 40 (or 42? ;-)
 float Extinction::SUBHORIZONTAL_AIRMASS=0.0f;
 
-Extinction::Extinction() : ext_coeff(0.20f)
+Extinction::Extinction()
 {
     QSettings* conf = StelApp::getInstance().getSettings();
     SUBHORIZONTAL_AIRMASS = (conf->value("astro/flag_extinction_below_horizon", true).toBool()? 42.0f : 0.0f);
+    ext_coeff=conf->value("landscape/atmospheric_extinction_coefficient", 0.2f).toFloat();
 }
 
 //  altAzPos is the NORMALIZED (!!!) star position vector AFTER REFRACTION, and its z component sin(altitude).
@@ -129,10 +130,13 @@ const float Refraction::MIN_APP_ALTITUDE_SIN_F=(float)Refraction::MIN_APP_ALTITU
 const double Refraction::TRANSITION_WIDTH_GEO_DEG_F=(float)Refraction::TRANSITION_WIDTH_GEO_DEG;
 const double Refraction::TRANSITION_WIDTH_APP_DEG_F=(float)Refraction::TRANSITION_WIDTH_APP_DEG;
 
-Refraction::Refraction() : pressure(1013.f), temperature(10.f),
+Refraction::Refraction() : //pressure(1013.f), temperature(10.f),
 	preTransfoMat(Mat4d::identity()), invertPreTransfoMat(Mat4d::identity()), preTransfoMatf(Mat4f::identity()), invertPreTransfoMatf(Mat4f::identity()),
 	postTransfoMat(Mat4d::identity()), invertPostTransfoMat(Mat4d::identity()), postTransfoMatf(Mat4f::identity()), invertPostTransfoMatf(Mat4f::identity())
 {
+  QSettings* conf = StelApp::getInstance().getSettings();
+  pressure=conf->value("landscape/pressure_mbar", 1013.0f).toFloat();
+  temperature=conf->value("landscape/temperature_C", 15.0f).toFloat();
 	updatePrecomputed();
 }
 
