@@ -32,6 +32,7 @@
 #include <QString>
 #include <QDebug>
 #include <QStringList>
+#include <QSettings>
 
 StelObjectMgr::StelObjectMgr() : searchRadiusPixel(30.f), distanceWeight(1.f)
 {
@@ -244,3 +245,156 @@ QStringList StelObjectMgr::listMatchingObjectsI18n(const QString& objPrefix, uns
 	result.sort();
 	return result;
 }
+
+int StelObjectMgr::getCustomInfoString(void)
+{
+	QSettings* conf = StelApp::getInstance().getSettings();
+
+	bool Name = conf->value("custom_selected_info/flag_show_name", false).toBool();
+	bool CatalogNumber = conf->value("custom_selected_info/flag_show_catalognumber", false).toBool();
+	bool Magnitude = conf->value("custom_selected_info/flag_show_magnitude", false).toBool();
+	bool RaDecJ2000 = conf->value("custom_selected_info/flag_show_radecj2000", false).toBool();
+	bool RaDecOfDate = conf->value("custom_selected_info/flag_show_radecofdate", false).toBool();
+	bool AltAz = conf->value("custom_selected_info/flag_show_altaz", false).toBool();
+	bool Distance = conf->value("custom_selected_info/flag_show_distance", false).toBool();
+	bool Size = conf->value("custom_selected_info/flag_show_size", false).toBool();
+	bool Extra1 = conf->value("custom_selected_info/flag_show_extra1", false).toBool();
+	bool Extra2 = conf->value("custom_selected_info/flag_show_extra2", false).toBool();
+	bool Extra3 = conf->value("custom_selected_info/flag_show_extra3", false).toBool();
+	bool HourAngle = conf->value("custom_selected_info/flag_show_hourangle", false).toBool();
+	bool AbsoluteMagnitude = conf->value("custom_selected_info/flag_show_absolutemagnitude", false).toBool();
+
+	int OctZero = 0x00000000;
+
+	int NameOct;
+	if (Name)
+	{
+		NameOct = StelObject::Name;
+	}
+	else
+	{
+		NameOct = OctZero;
+	}
+
+	int CatalogNumberOct;
+	if (CatalogNumber)
+	{
+		CatalogNumberOct = StelObject::CatalogNumber;
+	}
+	else
+	{
+		CatalogNumberOct = OctZero;
+	}
+
+	int MagnitudeOct;
+	if (Magnitude)
+	{
+		MagnitudeOct = StelObject::Magnitude;
+	}
+	else
+	{
+		MagnitudeOct = OctZero;
+	}
+
+	int RaDecJ2000Oct;
+	if (RaDecJ2000)
+	{
+		RaDecJ2000Oct = StelObject::RaDecJ2000;
+	}
+	else
+	{
+		RaDecJ2000Oct = OctZero;
+	}
+
+	int RaDecOfDateOct;
+	if (RaDecOfDate)
+	{
+		RaDecOfDateOct = StelObject::RaDecOfDate;
+	}
+	else
+	{
+		RaDecOfDateOct = OctZero;
+	}
+
+	int AltAzOct;
+	if (AltAz)
+	{
+		AltAzOct = StelObject::AltAzi;
+	}
+	else
+	{
+		AltAzOct = OctZero;
+	}
+
+	int DistanceOct;
+	if (Distance)
+	{
+		DistanceOct = StelObject::Distance;
+	}
+	else
+	{
+		DistanceOct = OctZero;
+	}
+
+	int SizeOct;
+	if (Size)
+	{
+		SizeOct = StelObject::Size;
+	}
+	else
+	{
+		SizeOct = OctZero;
+	}
+
+	int Extra1Oct;
+	if (Extra1)
+	{
+		Extra1Oct = StelObject::Extra1;
+	}
+	else
+	{
+		Extra1Oct = OctZero;
+	}
+
+	int Extra2Oct;
+	if (Extra2)
+	{
+		Extra2Oct = StelObject::Extra2;
+	}
+	else
+	{
+		Extra2Oct = OctZero;
+	}
+
+	int Extra3Oct;
+	if (Extra3)
+	{
+		Extra3Oct = StelObject::Extra3;
+	}
+	else
+	{
+		Extra3Oct = OctZero;
+	}
+
+	int HourAngleOct;
+	if (HourAngle)
+	{
+		HourAngleOct = StelObject::HourAngle;
+	}
+	else
+	{
+		HourAngleOct = OctZero;
+	}
+
+	int AbsoluteMagnitudeOct;
+	if (AbsoluteMagnitude)
+	{
+		AbsoluteMagnitudeOct = StelObject::AbsoluteMagnitude;
+	}
+	else
+	{
+		AbsoluteMagnitudeOct = OctZero;
+	}
+
+	return (NameOct|CatalogNumberOct|MagnitudeOct|RaDecJ2000Oct|RaDecOfDateOct|AltAzOct|DistanceOct|SizeOct|Extra1Oct|Extra2Oct|Extra3Oct|HourAngleOct|AbsoluteMagnitudeOct);
+}
