@@ -25,6 +25,10 @@
 #include <QObject>
 #include <QImage>
 #include <QtOpenGL>
+//FIXME: After fully migrate to Qt 4.8 this condition need drop
+#if QT_VERSION>=0x040800
+#include <QGLFunctions>
+#endif
 
 class QFile;
 class StelTextureMgr;
@@ -65,7 +69,13 @@ private:
 //! @class StelTexture
 //! Base texture class. For creating an instance, use StelTextureMgr::createTexture() and StelTextureMgr::createTextureThread()
 //! @sa StelTextureSP
-class StelTexture : public QObject
+class StelTexture
+//FIXME: After fully migrate to Qt 4.8 this condition need drop
+#if QT_VERSION>=0x040800
+		: public QObject, protected QGLFunctions
+#else
+		: public QObject
+#endif
 {
 	Q_OBJECT
 
@@ -91,6 +101,7 @@ public:
 	//! Bind the texture so that it can be used for openGL drawing (calls glBindTexture).
 	//! If the texture is lazyly loaded, this starts the loading and return false immediately.
 	//! @return true if the binding successfully occured, false if the texture is not yet loaded.
+	
 	bool bind();
 
 	//! Return whether the texture can be binded, i.e. it is fully loaded
