@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
 #include <functional>
@@ -75,6 +75,7 @@ double MeteorMgr::getCallOrder(StelModuleActionName actionName) const
 void MeteorMgr::setZHR(int zhr)
 {
 	ZHR = zhr;
+	emit zhrChanged(zhr);
 }
 
 int MeteorMgr::getZHR()
