@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
 #include "StarWrapper.hpp"
@@ -48,9 +48,14 @@ QString StarWrapperBase::getInfoString(const StelCore *core, const InfoStringGro
 	QTextStream oss(&str);
 
 	if (flags&Magnitude)
-		oss << q_("Magnitude: <b>%1</b> (B-V: %2)").arg(QString::number(getVMagnitude(core), 'f', 2), QString::number(getBV(), 'f', 2)) << "<br>";
-
-	oss << getPositionInfoString(core, flags);
+	{
+	    oss << q_("Magnitude: <b>%1</b> (B-V: %2)").arg(QString::number(getVMagnitude(core, false), 'f', 2), QString::number(getBV(), 'f', 2)) << "<br>";
+            if (core->getSkyDrawer()->getFlagHasAtmosphere())
+            {
+                oss << q_("Apparent Magnitude: <b>%1</b> (by extinction)").arg(QString::number(getVMagnitude(core, true), 'f', 2)) << "<br>";
+            }
+        }
+        oss << getPositionInfoString(core, flags);
 
 	StelObject::postProcessInfoString(str, flags);
 
@@ -105,11 +110,18 @@ QString StarWrapper1::getInfoString(const StelCore *core, const InfoStringGroup&
 	}
 
 	if (flags&Magnitude)
-		oss << q_("Magnitude: <b>%1</b> (B-V: %2)").arg(QString::number(getVMagnitude(core), 'f', 2),
-														QString::number(s->getBV(), 'f', 2)) << "<br>";
+	{
+	    if (core->getSkyDrawer()->getFlagHasAtmosphere())
+                oss << q_("Magnitude: <b>%1</b> (extincted to: <b>%2</b>. B-V: <b>%3</b>)").arg(QString::number(getVMagnitude(core, false), 'f', 2),
+											      QString::number(getVMagnitude(core, true), 'f', 2),
+											      QString::number(s->getBV(), 'f', 2)) << "<br>";
+	    else
+		oss << q_("Magnitude: <b>%1</b> (B-V: <b>%2</b>)").arg(QString::number(getVMagnitude(core, false), 'f', 2),
+								       QString::number(s->getBV(), 'f', 2)) << "<br>";
+	}
 
 	if ((flags&AbsoluteMagnitude) && s->plx && !isNan(s->plx) && !isInf(s->plx))
-		oss << q_("Absolute Magnitude: %1").arg(getVMagnitude(core)+5.*(1.+std::log10(0.00001*s->plx)), 0, 'f', 2) << "<br>";
+		oss << q_("Absolute Magnitude: %1").arg(getVMagnitude(core, false)+5.*(1.+std::log10(0.00001*s->plx)), 0, 'f', 2) << "<br>";
 
 	oss << getPositionInfoString(core, flags);
 
