@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
 #include "StelApp.hpp"
@@ -43,12 +43,24 @@
 #include <QGraphicsWidget>
 #include <QGraphicsProxyWidget>
 #include <QGraphicsLinearLayout>
+#include <QSettings>
 
-StelButton::StelButton(QGraphicsItem* parent, const QPixmap& apixOn, const QPixmap& apixOff,
-		const QPixmap& apixHover, QAction* aaction, bool noBackground) :
-			QGraphicsPixmapItem(apixOff, parent), pixOn(apixOn), pixOff(apixOff), pixHover(apixHover),
-			checked(ButtonStateOff), action(aaction), noBckground(noBackground), isTristate_(false),
-			opacity(1.), hoverOpacity(0.)
+StelButton::StelButton(QGraphicsItem* parent,
+                       const QPixmap& apixOn,
+                       const QPixmap& apixOff,
+                       const QPixmap& apixHover,
+                       QAction* aaction,
+                       bool noBackground) :
+	QGraphicsPixmapItem(apixOff, parent),
+	pixOn(apixOn),
+	pixOff(apixOff),
+	pixHover(apixHover),
+	checked(ButtonStateOff),
+	action(aaction),
+	noBckground(noBackground),
+	isTristate_(false),
+	opacity(1.),
+	hoverOpacity(0.)
 {
 	Q_ASSERT(!pixOn.isNull());
 	Q_ASSERT(!pixOff.isNull());
@@ -69,24 +81,41 @@ StelButton::StelButton(QGraphicsItem* parent, const QPixmap& apixOn, const QPixm
 
 	if (action!=NULL)
 	{
-		QObject::connect(action, SIGNAL(toggled(bool)), this, SLOT(setChecked(bool)));
+		QObject::connect(action, SIGNAL(toggled(bool)),
+		                 this, SLOT(setChecked(bool)));
 		if (action->isCheckable())
 		{
 			setChecked(action->isChecked());
-			QObject::connect(this, SIGNAL(toggled(bool)), action, SLOT(setChecked(bool)));
+			QObject::connect(this, SIGNAL(toggled(bool)),
+			                 action, SLOT(setChecked(bool)));
 		}
 		else
 		{
-			QObject::connect(this, SIGNAL(triggered()), action, SLOT(trigger()));
+			QObject::connect(this, SIGNAL(triggered()),
+			                 action, SLOT(trigger()));
 		}
 	}
 }
 
-StelButton::StelButton(QGraphicsItem* parent, const QPixmap& apixOn, const QPixmap& apixOff, const QPixmap& apixNoChange,
-		const QPixmap& apixHover, QAction* aaction, bool noBackground, bool isTristate) :
-			QGraphicsPixmapItem(apixOff, parent), pixOn(apixOn), pixOff(apixOff), pixNoChange(apixNoChange), pixHover(apixHover),
-			checked(ButtonStateOff), action(aaction), noBckground(noBackground), isTristate_(isTristate),
-			opacity(1.), hoverOpacity(0.)
+StelButton::StelButton(QGraphicsItem* parent,
+                       const QPixmap& apixOn,
+                       const QPixmap& apixOff,
+                       const QPixmap& apixNoChange,
+                       const QPixmap& apixHover,
+                       QAction* aaction,
+                       bool noBackground,
+                       bool isTristate) :
+	QGraphicsPixmapItem(apixOff, parent),
+	pixOn(apixOn),
+	pixOff(apixOff),
+	pixNoChange(apixNoChange),
+	pixHover(apixHover),
+	checked(ButtonStateOff),
+	action(aaction),
+	noBckground(noBackground),
+	isTristate_(isTristate),
+	opacity(1.),
+	hoverOpacity(0.)
 {
 	Q_ASSERT(!pixOn.isNull());
 	Q_ASSERT(!pixOff.isNull());
@@ -94,7 +123,8 @@ StelButton::StelButton(QGraphicsItem* parent, const QPixmap& apixOn, const QPixm
 	redMode = StelApp::getInstance().getVisionModeNight();
 	pixOnRed = StelButton::makeRed(pixOn);
 	pixOffRed = StelButton::makeRed(pixOff);
-	if (isTristate_) {
+	if (isTristate_)
+	{
 		Q_ASSERT(!pixNoChange.isNull());
 		pixNoChangeRed = StelButton::makeRed(pixNoChange);
 	}
@@ -107,27 +137,33 @@ StelButton::StelButton(QGraphicsItem* parent, const QPixmap& apixOn, const QPixm
 	setAcceptsHoverEvents(true);
 	timeLine = new QTimeLine(250, this);
 	timeLine->setCurveShape(QTimeLine::EaseOutCurve);
-	connect(timeLine, SIGNAL(valueChanged(qreal)), this, SLOT(animValueChanged(qreal)));
+	connect(timeLine, SIGNAL(valueChanged(qreal)),
+	        this, SLOT(animValueChanged(qreal)));
 
 	if (action!=NULL)
 	{
-		QObject::connect(action, SIGNAL(toggled(bool)), this, SLOT(setChecked(bool)));
+		QObject::connect(action, SIGNAL(toggled(bool)),
+		                 this, SLOT(setChecked(bool)));
 		if (action->isCheckable())
 		{
 			setChecked(action->isChecked());
-			QObject::connect(this, SIGNAL(toggled(bool)), action, SLOT(setChecked(bool)));
+			QObject::connect(this, SIGNAL(toggled(bool)),
+			                 action, SLOT(setChecked(bool)));
 		}
 		else
 		{
-			QObject::connect(this, SIGNAL(triggered()), action, SLOT(trigger()));
+			QObject::connect(this, SIGNAL(triggered()),
+			                 action, SLOT(trigger()));
 		}
 	}
 }
 
-int StelButton::toggleChecked(int checked) {
+int StelButton::toggleChecked(int checked)
+{
 	if (!isTristate_)
 		checked = !!!checked;
-	else {
+	else
+	{
 		if (++checked > ButtonStateNoChange)
 			checked = ButtonStateOff;
 	}
@@ -168,22 +204,22 @@ void StelButton::mouseReleaseEvent(QGraphicsSceneMouseEvent*)
 
 void StelButton::updateIcon()
 {
-	if (opacity<0.)
-		opacity=0;
+	if (opacity < 0.)
+		opacity = 0;
 	QPixmap pix(pixOn.size());
 	pix.fill(QColor(0,0,0,0));
 	QPainter painter(&pix);
 	painter.setOpacity(opacity);
 	if (!pixBackground.isNull() && noBckground==false)
-		painter.drawPixmap(0,0, redMode ? pixBackgroundRed : pixBackground);
+		painter.drawPixmap(0, 0, redMode ? pixBackgroundRed : pixBackground);
 	painter.drawPixmap(0, 0,
 		(isTristate_ && checked == ButtonStateNoChange) ? (redMode ? pixNoChangeRed : pixNoChange) :
 		(checked == ButtonStateOn) ? (redMode ? pixOnRed : pixOn) :
 		/* (checked == ButtonStateOff) ? */ (redMode ? pixOffRed : pixOff));
-	if (hoverOpacity>0)
+	if (hoverOpacity > 0)
 	{
-		painter.setOpacity(hoverOpacity*opacity);
-		painter.drawPixmap(0,0, redMode ? pixHoverRed : pixHover);
+		painter.setOpacity(hoverOpacity * opacity);
+		painter.drawPixmap(0, 0, redMode ? pixHoverRed : pixHover);
 	}
 	setPixmap(pix);
 }
@@ -200,6 +236,13 @@ void StelButton::setChecked(int b)
 	updateIcon();
 }
 
+void StelButton::setBackgroundPixmap(const QPixmap &newBackground)
+{
+	pixBackground = newBackground;
+	pixBackgroundRed = makeRed(newBackground);
+	updateIcon();
+}
+
 QPixmap StelButton::makeRed(const QPixmap& p)
 {
 	QImage im = p.toImage().convertToFormat(QImage::Format_ARGB32);
@@ -313,9 +356,16 @@ void LeftStelBar::setRedMode(bool b)
 	}
 }
 
-BottomStelBar::BottomStelBar(QGraphicsItem* parent, const QPixmap& pixLeft, const QPixmap& pixRight,
-		const QPixmap& pixMiddle, const QPixmap& pixSingle) : QGraphicsItem(parent), pixBackgroundLeft(pixLeft), pixBackgroundRight(pixRight),
-		pixBackgroundMiddle(pixMiddle), pixBackgroundSingle(pixSingle)
+BottomStelBar::BottomStelBar(QGraphicsItem* parent,
+                             const QPixmap& pixLeft,
+                             const QPixmap& pixRight,
+                             const QPixmap& pixMiddle,
+                             const QPixmap& pixSingle) :
+	QGraphicsItem(parent),
+	pixBackgroundLeft(pixLeft),
+	pixBackgroundRight(pixRight),
+	pixBackgroundMiddle(pixMiddle),
+	pixBackgroundSingle(pixSingle)
 {
 	// The text is dummy just for testing
 	datetime = new QGraphicsSimpleTextItem("2008-02-06  17:33", this);
@@ -358,17 +408,17 @@ BottomStelBar::~BottomStelBar()
 void BottomStelBar::addButton(StelButton* button, const QString& groupName, const QString& beforeActionName)
 {
 	QList<StelButton*>& g = buttonGroups[groupName].elems;
-	bool done=false;
-	for (int i=0;i<g.size();++i)
+	bool done = false;
+	for (int i=0; i<g.size(); ++i)
 	{
 		if (g[i]->action && g[i]->action->objectName()==beforeActionName)
 		{
 			g.insert(i, button);
-			done=true;
+			done = true;
 			break;
 		}
 	}
-	if (done==false)
+	if (done == false)
 		g.append(button);
 
 	button->setVisible(true);
@@ -381,7 +431,7 @@ void BottomStelBar::addButton(StelButton* button, const QString& groupName, cons
 StelButton* BottomStelBar::hideButton(const QString& actionName)
 {
 	QString gName;
-	StelButton* bToRemove=NULL;
+	StelButton* bToRemove = NULL;
 	for (QMap<QString, ButtonGroup>::iterator iter=buttonGroups.begin();iter!=buttonGroups.end();++iter)
 	{
 		int i=0;
@@ -389,7 +439,7 @@ StelButton* BottomStelBar::hideButton(const QString& actionName)
 		{
 			if (b->action && b->action->objectName()==actionName)
 			{
-				gName=iter.key();
+				gName = iter.key();
 				bToRemove = b;
 				iter.value().elems.removeAt(i);
 				break;
@@ -397,9 +447,9 @@ StelButton* BottomStelBar::hideButton(const QString& actionName)
 			++i;
 		}
 	}
-	if (bToRemove==NULL)
+	if (bToRemove == NULL)
 		return NULL;
-	if (buttonGroups[gName].elems.size()==0)
+	if (buttonGroups[gName].elems.size() == 0)
 	{
 		buttonGroups.remove(gName);
 	}
@@ -416,15 +466,18 @@ void BottomStelBar::setGroupMargin(const QString& groupName, int left, int right
 {
 	if (!buttonGroups.contains(groupName))
 		return;
-	buttonGroups[groupName].leftMargin=left;
-	buttonGroups[groupName].rightMargin=right;
+	buttonGroups[groupName].leftMargin = left;
+	buttonGroups[groupName].rightMargin = right;
 	updateButtonsGroups();
 }
 
 //! Change the background of a group
-void BottomStelBar::setGroupBackground(const QString& groupName, const QPixmap& pixLeft,
-						const QPixmap& pixRight,  const QPixmap& pixMiddle,
-						const QPixmap& pixSingle){
+void BottomStelBar::setGroupBackground(const QString& groupName,
+                                       const QPixmap& pixLeft,
+                                       const QPixmap& pixRight,
+                                       const QPixmap& pixMiddle,
+                                       const QPixmap& pixSingle)
+{
 
 	if (!buttonGroups.contains(groupName))
 		return;
@@ -434,7 +487,6 @@ void BottomStelBar::setGroupBackground(const QString& groupName, const QPixmap&
 	buttonGroups[groupName].pixBackgroundMiddle = new QPixmap(pixMiddle);
 	buttonGroups[groupName].pixBackgroundSingle = new QPixmap(pixSingle);
 	updateButtonsGroups();
-
 }
 
 QRectF BottomStelBar::getButtonsBoundingRect() const
@@ -460,63 +512,65 @@ QRectF BottomStelBar::getButtonsBoundingRect() const
 
 void BottomStelBar::updateButtonsGroups()
 {
-	double x=0;
-	double y = datetime->boundingRect().height()+3;
+	double x = 0;
+	double y = datetime->boundingRect().height() + 3;
 	for (QMap<QString, ButtonGroup >::iterator iter=buttonGroups.begin();iter!=buttonGroups.end();++iter)
 	{
-		if (iter.value().elems.empty())
+		ButtonGroup& group = iter.value();
+		QList<StelButton*>& buttons = group.elems;
+		if (buttons.empty())
 			continue;
-		x+=iter.value().leftMargin;
-		int n=0;
-		foreach (StelButton* b, iter.value().elems)
+		x += group.leftMargin;
+		int n = 0;
+		foreach (StelButton* b, buttons)
 		{
 			// We check if the group has its own background if not the case
 			// We apply a default background.
-			if (n==0)
+			if (n == 0)
 			{
-				if (iter.value().elems.size()==1)
+				if (buttons.size() == 1)
 				{
-					if (iter.value().pixBackgroundSingle == NULL)
-						b->pixBackground = pixBackgroundSingle;
+					if (group.pixBackgroundSingle == NULL)
+						b->setBackgroundPixmap(pixBackgroundSingle);
 					else
-						b->pixBackground = *(iter.value().pixBackgroundSingle);
+						b->setBackgroundPixmap(*group.pixBackgroundSingle);
 				}
 				else
 				{
-					if (iter.value().pixBackgroundLeft == NULL)
-						b->pixBackground = pixBackgroundLeft;
+					if (group.pixBackgroundLeft == NULL)
+						b->setBackgroundPixmap(pixBackgroundLeft);
 					else
-						b->pixBackground = *(iter.value().pixBackgroundLeft);
+						b->setBackgroundPixmap(*group.pixBackgroundLeft);
 				}
 			}
-			else if (n==iter.value().elems.size()-1)
+			else if (n == buttons.size()-1)
 			{
-				if (iter.value().elems.size()!=1)
+				if (buttons.size() != 1)
 				{
-					if (iter.value().pixBackgroundSingle == NULL)
-						b->pixBackground = pixBackgroundSingle;
+					if (group.pixBackgroundSingle == NULL)
+						b->setBackgroundPixmap(pixBackgroundSingle);
 					else
-						b->pixBackground = *(iter.value().pixBackgroundSingle);
+						b->setBackgroundPixmap(*group.pixBackgroundSingle);
 				}
-				if (iter.value().pixBackgroundRight == NULL)
-					b->pixBackground = pixBackgroundRight;
+				if (group.pixBackgroundRight == NULL)
+					b->setBackgroundPixmap(pixBackgroundRight);
 				else
-					b->pixBackground = *(iter.value().pixBackgroundRight);
+					b->setBackgroundPixmap(*group.pixBackgroundRight);
 			}
 			else
 			{
-				if (iter.value().pixBackgroundMiddle == NULL)
-					b->pixBackground = pixBackgroundMiddle;
+				if (group.pixBackgroundMiddle == NULL)
+					b->setBackgroundPixmap(pixBackgroundMiddle);
 				else
-					b->pixBackground = *(iter.value().pixBackgroundMiddle);
+					b->setBackgroundPixmap(*group.pixBackgroundMiddle);
 			}
 			// Update the button pixmap
 			b->animValueChanged(0.);
 			b->setPos(x, y);
-			x+=b->pixOn.width();
+			x += b->getButtonPixmapWidth();
 			++n;
 		}
-		x+=iter.value().rightMargin;
+		x+=group.rightMargin;
 	}
 	updateText(true);
 }
@@ -545,13 +599,21 @@ void BottomStelBar::updateText(bool updatePos)
 		location->setText(newLocation);
 	}
 
+	QSettings* confSettings = StelApp::getInstance().getSettings();
 	QString str;
 	QTextStream wos(&str);
 	wos << "FOV " << qSetRealNumberPrecision(3) << core->getMovementMgr()->getCurrentFov() << QChar(0x00B0);
 	if (fov->text()!=str)
 	{
 		updatePos = true;
-		fov->setText(str);
+		if (confSettings->value("gui/flag_show_fov", true).toBool())
+		{
+			fov->setText(str);
+		}
+		else
+		{
+			fov->setText("");
+		}
 	}
 
 	str="";
@@ -560,7 +622,14 @@ void BottomStelBar::updateText(bool updatePos)
 	if (fps->text()!=str)
 	{
 		updatePos = true;
-		fps->setText(str);
+		if (confSettings->value("gui/flag_show_fps", true).toBool())
+		{
+			fps->setText(str);
+		}
+		else
+		{
+			fps->setText("");
+		}
 	}
 
 	if (updatePos)
